@@ -26,7 +26,7 @@
 #' @param type (\code{character}): The type of subsampling to be implemented. By default this is classical rarefaction (\code{"cr"}). (\code{"oxw"}) stands for occurrence weighted by-list subsampling. If set to (\code{"sqs"}), the program will execute the shareholder quorum subsampling algorithm as it was suggested by Alroy (2010). Setting the argument to \code{"none"} will invoke no subsamling, but the applied function will be iterated on the trials, nevertheless.
 #' @param FUN (\code{function}): The function to be iteratively executed on the results of the subsampling trials. If set to \code{NULL}, no function will be executed, and the subsampled datasets will be returned as a \code{list}. By default set to the \code{\link{divDyn}} function. The function must have an argument called \code{x}, that represents the dataset resulting from a subsampling trial (or the entire dataset). Arguments of the \code{subsample} function call will be searched for potential arguments of this function, which means that already provided variables (e.g. \code{bin} and \code{tax}) will also be used. You can also provide additional arguments (similarly to the \code{\link[base]{apply}} iterator). Functions that allow arguments to pass through (that have argument '...') are not allowed, as well as functions that have the same arguments as \code{subsample} but would require different values.
 #' @param output (\code{character}): If the function output are vectors or matrices, the \code{"arit"} and \code{"geom"} values will trigger simple averaging with arithmetic or geometric means. If the function output of a single trial is again a \code{vector} or a \code{matrix}, setting the output to \code{"dist"} will return the calculated results of every trial, organized in a \code{list} of independent variables (e.g. if the function output is value, the return will contain a single \code{vector}, if it is a \code{vector}, the output will be a list of \code{vector}s, if the function output is a \code{data.frame}, the output will be a \code{list} of \code{matrix} class objects). If \code{output="list"}, the structure of the original function output will be retained, and the results of the individual trials will be concatenated to a \code{list}.
-#' @param keep (\code{numeric}): The bins, which will not be subsampled but will be added to the subsampling trials. NIf the number of occurrences does not reach the subsampling quota, by default it will not be represented in the subsampling trials. You can force their inclusion with the \code{keep} argument separetely (for all, see the \code{useFailed} argument). 
+#' @param keep (\code{numeric}): The bins which will not be subsampled but will be added to the subsampling trials. If the number of occurrences does not reach the subsampling quota, by default it will not be represented in the subsampling trials. You can force their inclusion with the \code{keep} argument separetely (for all, see the \code{useFailed} argument). 
 #' @param rem  (\code{numeric}): The bins, which will be removed from the dataset before the subsampling trials.
 #' @param duplicates (\code{logical} ): Toggles whether multiple entries from the same taxon (\code{"tax"}) and collection (\code{"coll"}) variables should be omitted. Useful for omitting occurrences of multiple species-level occurrences of the same genus. By default these are allowed through analyses (\code{duplicates=TRUE}), setting this to \code{FALSE} will require you to provide a collection variable. (\code{coll})
 #' @param coll (\code{character}): The variable name of the collection identifiers. 
@@ -658,6 +658,12 @@ subsample<- function(x,
 	
 	# 6. ITERATION - rerun the subsampling function in loops, and run the applied function
 
+	# In case there is random number generation in RCpp
+	if(type=="cr"){
+		# in case the seed was not set earlier
+		if(!exists(".Random.seed")) set.seed(NULL)
+	}
+
 	# 6A.  FOR-type iteration
 	if(loop=="for"){
 	
@@ -677,8 +683,17 @@ subsample<- function(x,
 					
 					#by-row method
 					if(!byUnit){
+
+						# generate a single random number,it will move the generator state forward
+						# as long as the state can be linked to the R RNG seed, this should work fine
+						seed <- sample(max(.Random.seed),1)
+						# message(seed)
+
+						# this is probably not necessary,but just in case
+						set.seed(seed)
+
 						# output of cpp function
-						binCRres<-.Call('_divDyn_CRbinwise', PACKAGE = 'divDyn', binVar, quoVar)
+						binCRres<-.Call('_divDyn_CRbinwise', PACKAGE = 'divDyn', binVar, quoVar, seed)
 					
 						# increase indexing (R)
 						binCRres[,1]<-binCRres[,1, drop=TRUE]+1
