@@ -9,7 +9,7 @@
                                                                        
 /* .Call calls */                                                      
 extern SEXP _divDyn_Counts(SEXP, SEXP);                                
-extern SEXP _divDyn_CRbinwise(SEXP, SEXP);         
+extern SEXP _divDyn_CRbinwise(SEXP, SEXP,SEXP);
 extern SEXP _divDyn_seqduplicated(SEXP); 
 extern SEXP _divDyn_fillLogical(SEXP, SEXP);
 extern SEXP _divDyn_fillNumeric(SEXP, SEXP, SEXP);     
@@ -17,7 +17,7 @@ extern SEXP _divDyn_fillCharacter(SEXP, SEXP);
                                                                        
 static const R_CallMethodDef CallEntries[] = {                         
     {"_divDyn_Counts",    (DL_FUNC) &_divDyn_Counts,    2},            
-    {"_divDyn_CRbinwise", (DL_FUNC) &_divDyn_CRbinwise, 2},            
+    {"_divDyn_CRbinwise", (DL_FUNC) &_divDyn_CRbinwise, 3},
     {"_divDyn_seqduplicated", (DL_FUNC) &_divDyn_seqduplicated, 1}, 
     {"_divDyn_fillLogical", (DL_FUNC) &_divDyn_fillLogical, 2},
     {"_divDyn_fillNumeric", (DL_FUNC) &_divDyn_fillNumeric, 3},          
